@@ -562,8 +562,8 @@ class Database:
             df = df.sort_index()
 
             df['ss_ratio'] = df['ss_ratio'].astype(float)
-            df['ss_shares'] = df['ss_shares'].astype('int64')
-            df['ss_dollars'] = df['ss_dollars'].astype('int64')
+            df['ss_shares'] = df['ss_shares'].astype(float)
+            df['ss_dollars'] = df['ss_dollars'].astype(float)
 
             return df
 
